@@ -7,7 +7,7 @@ use crate::cassandra::value::Value;
 
 use crate::cassandra_sys::cass_aggregate_meta_argument_count;
 use crate::cassandra_sys::cass_aggregate_meta_argument_type;
-use crate::cassandra_sys::cass_aggregate_meta_field_by_name;
+use crate::cassandra_sys::cass_aggregate_meta_field_by_name_n;
 use crate::cassandra_sys::cass_aggregate_meta_final_func;
 use crate::cassandra_sys::cass_aggregate_meta_full_name;
 use crate::cassandra_sys::cass_aggregate_meta_init_cond;
@@ -18,8 +18,8 @@ use crate::cassandra_sys::cass_aggregate_meta_state_type;
 use crate::cassandra_sys::cass_iterator_fields_from_aggregate_meta;
 use crate::cassandra_sys::raw2utf8;
 use crate::cassandra_sys::CassAggregateMeta as _CassAggregateMeta;
-use std::ffi::CString;
 use std::mem;
+use std::os::raw::c_char;
 
 /// Metadata about a cassandra aggregate
 #[derive(Debug)]
@@ -103,8 +103,8 @@ impl AggregateMeta {
     /// access to the column data found in the underlying "aggregates" metadata table.
     pub fn field_by_name(&self, name: &str) -> Option<Value> {
         unsafe {
-            let name_cstr = CString::new(name).expect("must be utf8");
-            let agg = cass_aggregate_meta_field_by_name(self.0, name_cstr.as_ptr());
+            let name_ptr = name.as_ptr() as *const c_char;
+            let agg = cass_aggregate_meta_field_by_name_n(self.0, name_ptr, name.len());
             if agg.is_null() {
                 None
             } else {
